@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-f08bddca20a80ffa9946fd4ac0a95a31
-key: aws_2MCeqgPoamsJfGJDJIhvYQ
+id: aws-0.13.0-14d0a32c7af7e2b03d60bff82d74a8d4
+key: aws_FeUDxrjglkQ4Lrrd4qJUZy
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,7 +55,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-2MCeqgPoamsJfGJDJIhvYQ
+hs-libraries: HSaws-0.13.0-FeUDxrjglkQ4Lrrd4qJUZy
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
@@ -74,7 +74,7 @@ depends:
     data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.10.1-06d6cae4a7dc7e652455c24a41eb9def
+    http-conduit-2.1.10.1-9bcd28b714a9db44a394bc84b9d644e0
     http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
